from setuptools import setup

setup(name='nav_env',
      version='0.0.1',
      install_requires=[
            'gym',
            'lgblkb-tools',
            ]  # And any other dependencies foo needs
)
